bank_codes = {
    '000': 'Banco Bankpar S.A.',
    '001': 'Banco do Brasil S.A.',
    '003': 'Banco da Amazônia S.A.',
    '004': 'Banco do Nordeste do Brasil S.A.',
    '012': 'Banco Standard de Investimentos S.A.',
    '014': 'Natixis Brasil S.A. Banco Múltiplo',
    '019': 'Banco Azteca do Brasil S.A.',
    '021': 'BANESTES S.A. Banco do Estado do Espírito Santo',
    '024': 'Banco de Pernambuco S.A. - BANDEPE',
    '025': 'Banco Alfa S.A.',
    '029': 'Banco Banerj S.A.',
    '031': 'Banco Beg S.A.',
    '033': 'Banco Santander (Brasil) S.A.',
    '036': 'Banco Bradesco BBI S.A.',
    '037': 'Banco do Estado do Pará S.A.',
    '039': 'Banco do Estado do Piauí S.A. - BEP',
    '040': 'Banco Cargill S.A.',
    '041': 'Banco do Estado do Rio Grande do Sul S.A.',
    '044': 'Banco BVA S.A.',
    '045': 'Banco Opportunity S.A.',
    '047': 'Banco do Estado de Sergipe S.A.',
    '062': 'Hipercard Banco Múltiplo S.A.',
    '063': 'Banco Ibi S.A. Banco Múltiplo',
    '064': 'Goldman Sachs do Brasil Banco Múltiplo S.A.',
    '065': 'Banco Bracce S.A.',
    '066': 'Banco Morgan Stanley S.A.',
    '069': 'BPN Brasil Banco Múltiplo S.A.',
    '070': 'BRB - Banco de Brasília S.A.',
    '072': 'Banco Rural Mais S.A.',
    '073': 'BB Banco Popular do Brasil S.A.',
    '074': 'Banco J. Safra S.A.',
    '075': 'Banco CR2 S.A.',
    '076': 'Banco KDB S.A.',
    '077-9': 'Banco Intermedium S.A.',
    '078': 'BES Investimento do Brasil S.A.-Banco de Investimento',
    '079': 'JBS Banco S.A.',
    '081-7': 'Concórdia Banco S.A.',
    '082-5': 'Banco Topázio S.A.',
    '083-3': 'Banco da China Brasil S.A.',
    '084': 'Unicred Norte do Paraná',
    '085-x': 'Cooperativa Central de Crédito Urbano-CECRED',
    '086-8': 'OBOE Crédito Financiamento e Investimento S.A.',
    '087-6': 'Cooperativa Unicred Central Santa Catarina',
    '088-4': 'Banco Randon S.A.',
    '089-2': 'Cooperativa de Crédito Rural da Região de Mogiana',
    '090-2': 'Cooperativa Central de Economia e Crédito Mutuo das Unicreds',
    '091-4': 'Unicred Central do Rio Grande do Sul',
    '092-2': 'Brickell S.A. Crédito, financiamento e Investimento',
    '094-2': 'Banco Petra S.A.',
    '096': 'Banco BM&F de Serviços de Liquidação e Custódia S.A',
    '097-3': 'Cooperativa Central de Crédito Noroeste Brasileiro Ltda.',
    '098-1': 'Credicorol Cooperativa de Crédito Rural',
    '099-x': 'Cooperativa Central de Economia e Credito Mutuo das Unicreds',
    '104': 'Caixa Econômica Federal',
    '107': 'Banco BBM S.A.',
    '168': 'HSBC Finance (Brasil) S.A. - Banco Múltiplo',
    '184': 'Banco Itaú BBA S.A.',
    '204': 'Banco Bradesco Cartões S.A.',
    '208': 'Banco BTG Pactual S.A.',
    '212': 'Banco Matone S.A.',
    '213': 'Banco Arbi S.A.',
    '214': 'Banco Dibens S.A.',
    '215': 'Banco Comercial e de Investimento Sudameris S.A.',
    '217': 'Banco John Deere S.A.',
    '218': 'Banco Bonsucesso S.A.',
    '222': 'Banco Credit Agricole Brasil S.A.',
    '224': 'Banco Fibra S.A.',
    '225': 'Banco Brascan S.A.',
    '229': 'Banco Cruzeiro do Sul S.A.',
    '230': 'Unicard Banco Múltiplo S.A.',
    '233': 'Banco GE Capital S.A.',
    '237': 'Banco Bradesco S.A.',
    '241': 'Banco Clássico S.A.',
    '243': 'Banco Máxima S.A.',
    '246': 'Banco ABC Brasil S.A.',
    '248': 'Banco Boavista Interatlântico S.A.',
    '249': 'Banco Investcred Unibanco S.A.',
    '250': 'Banco Schahin S.A.',
    '254': 'Paraná Banco S.A.',
    '263': 'Banco Cacique S.A.',
    '265': 'Banco Fator S.A.',
    '266': 'Banco Cédula S.A.',
    '300': 'Banco de La Nacion Argentina',
    '318': 'Banco BMG S.A.',
    '320': 'Banco Industrial e Comercial S.A.',
    '341': 'Itaú Unibanco S.A.',
    '356': 'Banco Real S.A.',
    '366': 'Banco Société Générale Brasil S.A.',
    '370': 'Banco WestLB do Brasil S.A.',
    '376': 'Banco J. P. Morgan S.A.',
    '389': 'Banco Mercantil do Brasil S.A.',
    '394': 'Banco Bradesco Financiamentos S.A.',
    '399': 'HSBC Bank Brasil S.A. - Banco Múltiplo',
    '409': 'UNIBANCO - União de Bancos Brasileiros S.A.',
    '412': 'Banco Capital S.A.',
    '422': 'Banco Safra S.A.',
    '453': 'Banco Rural S.A.',
    '456': 'Banco de Tokyo-Mitsubishi UFJ Brasil S.A.',
    '464': 'Banco Sumitomo Mitsui Brasileiro S.A.',
    '473': 'Banco Caixa Geral - Brasil S.A.',
    '477': 'Citibank N.A.',
    '479': 'Banco ItaúBank S.A',
    '487': 'Deutsche Bank S.A. - Banco Alemão',
    '488': 'JPMorgan Chase Bank',
    '492': 'ING Bank N.V.',
    '494': 'Banco de La Republica Oriental del Uruguay',
    '495': 'Banco de La Provincia de Buenos Aires',
    '505': 'Banco Credit Suisse (Brasil) S.A.',
    '600': 'Banco Luso Brasileiro S.A.',
    '604': 'Banco Industrial do Brasil S.A.',
    '610': 'Banco VR S.A.',
    '611': 'Banco Paulista S.A.',
    '612': 'Banco Guanabara S.A.',
    '613': 'Banco Pecúnia S.A.',
    '623': 'Banco Panamericano S.A.',
    '626': 'Banco Ficsa S.A.',
    '630': 'Banco Intercap S.A.',
    '633': 'Banco Rendimento S.A.',
    '634': 'Banco Triângulo S.A.',
    '637': 'Banco Sofisa S.A.',
    '638': 'Banco Prosper S.A.',
    '641': 'Banco Alvorada S.A.',
    '643': 'Banco Pine S.A.',
    '652': 'Itaú Unibanco Holding S.A.',
    '653': 'Banco Indusval S.A.',
    '654': 'Banco A.J.Renner S.A.',
    '655': 'Banco Votorantim S.A.',
    '707': 'Banco Daycoval S.A.',
    '719': 'Banif-Banco Internacional do Funchal (Brasil)S.A.',
    '721': 'Banco Credibel S.A.',
    '724': 'Banco Porto Seguro S.A.',
    '734': 'Banco Gerdau S.A.',
    '735': 'Banco Pottencial S.A.',
    '738': 'Banco Morada S.A.',
    '739': 'Banco BGN S.A.',
    '740': 'Banco Barclays S.A.',
    '741': 'Banco Ribeirão Preto S.A.',
    '743': 'Banco Semear S.A.',
    '744': 'BankBoston N.A.',
    '745': 'Banco Citibank S.A.',
    '746': 'Banco Modal S.A.',
    '747': 'Banco Rabobank International Brasil S.A.',
    '748': 'Banco Cooperativo Sicredi S.A.',
    '749': 'Banco Simples S.A.',
    '751': 'Dresdner Bank Brasil S.A. - Banco Múltiplo',
    '752': 'Banco BNP Paribas Brasil S.A.',
    '753': 'NBC Bank Brasil S.A. - Banco Múltiplo',
    '755': 'Bank of America Merrill Lynch Banco Múltiplo S.A.',
    '756': 'Banco Cooperativo do Brasil S.A. - BANCOOB',
    '757': 'Banco KEB do Brasil S.A.',
    'M03': 'Banco Fiat S.A.',
    'M06': 'Banco de Lage Landen Brasil S.A.',
    'M07': 'Banco GMAC S.A.',
    'M08': 'Banco Citicard S.A.',
    'M09': 'Banco Itaucred Financiamentos S.A.',
    'M10': 'Banco Moneo S.A.',
    'M11': 'Banco IBM S.A.',
    'M12': 'Banco Maxinvest S.A.',
    'M13': 'Banco Tricury S.A.',
    'M14': 'Banco Volkswagen S.A.',
    'M15': 'Banco BRJ S.A.',
    'M16': 'Banco Rodobens S.A.',
    'M17': 'Banco Ourinvest S.A.',
    'M18': 'Banco Ford S.A.',
    'M19': 'Banco CNH Capital S.A.',
    'M20': 'Banco Toyota do Brasil S.A.',
    'M21': 'Banco Daimlerchrysler S.A.',
    'M22': 'Banco Honda S.A.',
    'M23': 'Banco Volvo (Brasil) S.A.',
    'M24': 'Banco PSA Finance Brasil S.A.'
}
